===========================================================
``psyclone.tests.psyir.frontend.fparser2_kind_params_test``
===========================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_kind_params_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_kind_params_test
